@@ -57,6 +57,8 @@ public:
 	argb inputBoxBackground = parseHexString("#32363E");
 	argb inputBoxBackgroundError = parseHexString("#E76A63");
 	std::string inputBoxRadius = "0";
+	std::string inputBoxDotGlyph = "●";
+	int inputBoxFontSize = 24;
 	bool animations = true;
 
 	/**
